@@ -7,7 +7,7 @@ use Exporter qw(import);
 use Module::Load;
 use YAML qw(LoadFile);
 
-our $VERSION = '0.0100'; # VERSION
+our $VERSION = '0.0200'; # VERSION
 
 our @EXPORT_OK = qw(config get_config add_schema_to_config rset resultset schema);
 
@@ -23,7 +23,7 @@ sub config {
     return $_config if $_config;
     my $config_path;
     if (-f 'config.yaml') {
-        $config_path = 'config.yaml'
+        $config_path = 'config.yaml';
     } elsif (-f 'config.yml') {
         $config_path = 'config.yml';
     } else {
@@ -44,28 +44,54 @@ sub add_schema_to_config {
 }
 
 sub schema {
-    my ($name) = @_;
+    my ( $name, $schema_cfg ) = @_;
+
     my $cfg = config();
 
+    # We weren't asked for a specific name
+    # try to get one from the default config
     if (not defined $name) {
-        if (keys %$cfg == 1) {
-            ($name) = keys %$cfg;
-        } elsif (keys %$cfg) {
-            $name = "default";
-        } else {
-            die "No schemas are configured";
-        }
+        my @names = keys %{$cfg}
+            or croak("No schemas are configured");
+
+        # Either pick the only one in the config or the default
+        $name = @names == 1 ? $names[0] : 'default';
     }
 
+    my $options = $cfg->{$name}
+        or croak("The schema $name is not configured");
+
+    # Schema specific configuration from the user
+    if ($schema_cfg) {
+        # Just return a new schema and do not save it
+        return _create_schema( $name, $schema_cfg );
+    }
+
+    # Return existing schemas, either by name
     return $_schemas->{$name} if $_schemas->{$name};
 
-    my $options = $cfg->{$name} or die "The schema $name is not configured";
+    # Or by alias
     if ( my $alias = $options->{alias} ) {
         $options = $cfg->{$alias}
-            or die "The schema alias $alias does not exist in the config";
+            or croak("The schema alias $alias does not exist in the config");
         return $_schemas->{$alias} if $_schemas->{$alias};
     }
 
+    # Create schema
+    my $schema = _create_schema( $name, $options );
+
+    return $_schemas->{$name} = $schema;
+}
+
+sub resultset {
+    my ($rset_name) = @_;
+    return schema()->resultset($rset_name);
+}
+
+sub rset { goto &resultset }
+
+sub _create_schema {
+    my ( $name, $options ) = @_;
     my @conn_info = $options->{connect_info}
         ? @{$options->{connect_info}}
         : @$options{qw(dsn user password options)};
@@ -79,7 +105,7 @@ sub schema {
     if ( my $schema_class = $options->{schema_class} ) {
         $schema_class =~ s/-/::/g;
         eval { load $schema_class };
-        die "Could not load schema_class $schema_class: $@" if $@;
+        croak("Could not load schema_class $schema_class: $@") if $@;
         if ( my $replicated = $options->{replicated} ) {
             $schema = $schema_class->clone;
             my %storage_options;
@@ -97,22 +123,15 @@ sub schema {
     } else {
         my $dbic_loader = 'DBIx::Class::Schema::Loader';
         eval { load $dbic_loader };
-        die "You must provide a schema_class option or install $dbic_loader."
+        croak("You must provide a schema_class option or install $dbic_loader.")
             if $@;
         $dbic_loader->naming( $options->{schema_loader_naming} || 'v7' );
         $schema = DBIx::Class::Schema::Loader->connect(@conn_info);
     }
 
-    return $_schemas->{$name} = $schema;
-};
-
-sub resultset {
-    my ($rset_name) = @_;
-    return schema()->resultset($rset_name);
+    return $schema;
 }
 
-sub rset { goto &resultset };
-
 # ABSTRACT: Just some syntax sugar for DBIx::Class
 
 
@@ -130,7 +149,7 @@ DBICx::Sugar - Just some syntax sugar for DBIx::Class
 
 =head1 VERSION
 
-version 0.0100
+version 0.0200
 
 =head1 SYNOPSIS
 
